#!/usr/bin/env python
# -*- encoding: utf-8 -*-

## the sole purpose of this file is so that I can run "python docker_sync" in
## the root of the project.  I don't know how it works, but it does. :-)

from cli import sync
sync()
